#
# spec file for package python-netutils
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-netutils
Version:        1.13.0
Release:        2.1
Summary:        Common helper functions useful in network automation
License:        Apache-2.0
URL:            https://netutils.readthedocs.io
Source:         https://github.com/networktocode/netutils/archive/refs/tags/v%{version}.tar.gz#/netutils-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module jinja2}
BuildRequires:  %{python_module legacycrypt if %python-base >= 3.13}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module toml}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-napalm
BuildArch:      noarch
%if 0%{?python_version_nodots} >= 313
Requires:       python-legacycrypt
%endif
%python_subpackages

%description
A Python library that is a collection of objects for common network automation tasks.

%prep
%autosetup -p1 -n netutils-%{version}
chmod -x netutils/lib_helpers.py

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}
rm -f %{buildroot}%{$python_sitelib}/{CHANGELOG.md,LICENSE,README.md}
}

%check
# test_is_fqdn_resolvable, test_fqdn_to_ip, test_tcp_ping: needs internet connection
# test_sphinx_build: needs Sphinx, which is a huge dependency just for the one test
%pytest -k "not (test_is_fqdn_resolvable or test_fqdn_to_ip or test_tcp_ping or test_sphinx_build)"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/netutils
%{python_sitelib}/netutils-%{version}.dist-info

%changelog
* Thu Apr 10 2025 Georg Pfuetzenreuter <georg.pfuetzenreuter@suse.com>
- Enable sle15_python_module_pythons to build for Python 3.11 on Leap
  (project is now Python 3.9+)
* Fri Apr  4 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.13.0
  * Added is_reversible_wildcardmask, netmask_to_wildcardmask,
    and wildcardmask_to_netmask functions.
  * Added aruba_os and aruba_osswitch parsers.
- Drop fix-version-in-pyproject.patch, fixed upstream
* Tue Jan 14 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.12.0
  * Added Python 3.13 support.
  * Removed Python 3.8 support.
- from version 1.11.0
  * (no changes reported)
- Add fix-version-in-pyproject.patch to fix version in pyproject.toml
- Drop use-legacycrypt-if-required.patch, merged upstream
- Update BuildRequires from pyproject.toml
* Tue Dec  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.10.0:
  * Added Functionality to ip_network filter to support method calls
    with kwargs.
  * Fix configuration parsers to allow newlines, no longer auto strip
    all newlines.
  * Added NIST URL creation and platform mapper.
  * Added DNA Center platform mappings.
  * Improved error message when duplicate line is parsed.
- Add patch use-legacycrypt-if-required.patch:
  * Use the legacycrypt module where we need to.
- Switch to autosetup macros.
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.1:
  * Standard automated updates to Flatbot files: OUI File,
    PROTOCOL Files.
  * #509 Fixed parsing of empty banner, and dual banner for Cisco
    platforms.
- update to 1.8.0:
  * Added support for Python 3.12.
  * Added local support of `distutils.version` now that Python
    3.12 deprecates disutils.
  * Added functions `compare_version_loose` and
    `compare_version_strict` based on `distutils.version`.
  * Added function `paloalto_panos_clean_newlines`.
  * Added various lib_mapper updates.
  * Added HP Comware parser.
* Fri Mar 15 2024 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Added the ability to hash a value via `hash_data` function.
  * Added the ability to sort IPs a value via `get_ips_sorted`
    function.
  * Added lib_mapper entries for `ruckus_smartzone`, `cisco_xe`,
    `huawei` and `cisco_xr`.
* Wed Dec 20 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * Added `ubiquiti_airos` parser.
  * Added `ACLRule` and `ACLRules` classes.
  * Added the `ip` functions `is_ip_range`, `is_ip_within`,
    `is_network`, and `get_range_ips`.
  * Added the `asn` function `int_to_asn` in the function.
  * Added `NETUTILSPARSER_LIB_MAPPER` and
    `NETUTILSPARSER_LIB_MAPPER_REVERSE` to lib mapper.
  * Added classy docs to view config parser classes.
  * Added Mikrotik, fastiron, and Panos parsers.
  * Added function to allow conversion from Panos curly bracket
    to set format.
  * Updated Interface mappings for FourHundredGigabitEthernet and
    TwoGigabitEthernet.
  * Added Encryption/Decryption/Comparison for Cisco & Juniper
    Type 9.
  * Added Regex functions to primarily be used wihin your Jinja2
    environment.
* Tue May  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.4.1
  [#]# Changed
  * #171 Allow protocol mapper to be auto-generated.
  * #197 Prepend OUI Flatbot step to delete existing branch.
  * #200 Allow bandwith to be represented without "ps" in
    bandwidth.
  [#]# Fixed
  * #206 Fix Passwords docs that show ASN details.
  * #209 Fixed interface_range_expansion with trailing constant.
  * #210 Install black into flat environment, change flat action
    name.
- Release 1.4.0
  [#]# Added
  * #163 Added IP is_classfull utility function.
  * #172 Added Aruba AOS-CX Parser.
  * #177 Added IOS-XR Parser.
  * #182 Added Mrv Optiswitch Parser.
  * #182 Added Extreme Netiron Parser.
  [#]# Changed
  * #178 Update OUI flatbot CI process.
  [#]# Fixed
  * #173 Fixes classfull address naming.
  * #183 Updates parser folder info, fix aruba tests.
  * #181 Fixes incorrect behavior when calling tcp_ping with
    timeout >= 3.
  [#]# Removed
  * #184 Removed redundant __init__ methods on Parser classes.
- Release 1.3.0
  * Added IOS Config parsing for get_path and
    get_path_with_children methods.
  * Added OUI mappings and built a flat ci process to manage
    freshness of data.
  * Added first getter feature with Napalm Getter feature.
  * Converted to mkdocs docs.
  * Added Citrix NetScaler Parser.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- v1.2.0 - 2022-08
  Added
  [#128] Documentation for Nokia SROS duplicate lines/duplicate line detection
  [#138] Added nxos_ssh to Napalm mapper
  Changed
  [#113] Updated lib mapping docs
  [#115] Switched build backend to poetry-core
  [#121] Update banner parsing for EOS
  [#129] Add type hints to the whole project and mypy testing setup and CI
  [#134] Updated CODEOWNERS
  Fixed
  [#122] Fixed encrypt type7
* Thu Jul 21 2022 Matej Cepl <mcepl@suse.com>
- Tighten %%%%files.
* Tue Jul 19 2022 Markéta Machová <mmachova@suse.com>
- Initial packaging (v1.1.0), needed by python-napalm
